@@ -1,7 +1,7 @@
 /*
  * Peony-Qt's Library
  *
- * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020, KylinSoft Co., Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,8 @@
 #include <QPaintEvent>
 #include <QPainter>
 
+#include <QStyleOptionButton>
+
 using namespace Peony;
 
 IconContainer::IconContainer(QWidget *parent) : QPushButton(parent)
@@ -32,6 +34,17 @@ IconContainer::IconContainer(QWidget *parent) : QPushButton(parent)
     setCheckable(false);
     setDefault(true);
     setFlat(true);
+
+    m_style = new IconContainerStyle;
+    setStyle(m_style);
+
+    //fix push button use as icon caused color issues
+    this->setProperty("isIcon", true);
+}
+
+IconContainer::~IconContainer()
+{
+    m_style->deleteLater();
 }
 
 void IconContainer::paintEvent(QPaintEvent *e)
@@ -39,6 +52,18 @@ void IconContainer::paintEvent(QPaintEvent *e)
     QPainter p(this);
     p.fillRect(this->rect(), this->palette().base());
     p.setPen(this->palette().dark().color());
-    p.drawRect(this->rect().adjusted(0, 0, -1, -1));
+    //p.drawRect(this->rect().adjusted(0, 0, -1, -1));
     QPushButton::paintEvent(e);
 }
+
+IconContainerStyle::IconContainerStyle() : QProxyStyle()
+{
+
+}
+
+void IconContainerStyle::drawControl(QStyle::ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const
+{
+    QStyleOptionButton opt = *qstyleoption_cast<const QStyleOptionButton *>(option);
+    opt.palette.setColor(QPalette::Highlight, Qt::transparent);
+    return QProxyStyle::drawControl(element, &opt, painter, widget);
+}
