@@ -33,7 +33,7 @@ class QMenu;
 
 namespace Peony {
 
-class PEONYCORESHARED_EXPORT LocationBar : public QWidget
+class LocationBar : public QWidget
 {
     Q_OBJECT
 public:
@@ -68,6 +68,8 @@ private:
     QMap<QString, QToolButton *> m_buttons;
     QToolButton *m_indicator;
     QMenu *m_indicator_menu;
+
+    const int ELIDE_TEXT_LENGTH = 16;
 };
 
 }
